@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 # Copyright 2010-2018 Brad Lanam Walnut Creek CA USA
-# Copyright 2020-2024 Brad Lanam Pleasant Hill CA
+# Copyright 2020 Brad Lanam Pleasant Hill CA
 #
 #
 #   The four headers: stdio.h, stdlib.h, sys/types.h, and sys/param.h
@@ -23,17 +23,7 @@
 #       #  define const
 #       # endif
 #       # if ! _key_void || ! _param_void_star
-#          typedef char *_pvoid;
-#       # else
-#          typedef void *_pvoid;
-#       # endif
-#
-#       # ifndef _
-#       #  if _proto_stdc
-#       #   define _(args) args
-#       #  else
-#       #   define _(args) ()
-#       #  endif
+#       #  define void char
 #       # endif
 #       #endif /* MKC_STANDARD_DEFS */
 #
@@ -50,7 +40,6 @@
 
 require_unit c-support
 
-_MKCONFIG_PREFIX=c
 _MKCONFIG_HASEMPTY=F
 _MKCONFIG_EXPORT=F
 PH_PREFIX="mkc_ph."
@@ -58,12 +47,6 @@ PH_STD=F
 PH_ALL=F
 
 precc='
-#if defined(__STDC__) || defined(__cplusplus) || defined(c_plusplus)
-# define _(x) x
-#else
-# define _(x) ()
-# define void char
-#endif
 #if defined(__cplusplus) || defined (c_plusplus)
 # define CPP_EXTERNS_BEG extern "C" {
 # define CPP_EXTERNS_END }
@@ -81,7 +64,8 @@ preconfigfile () {
 
   # log all of the compiler and linker options
   for nm in CC CFLAGS_OPTIMIZE CFLAGS_DEBUG CFLAGS_INCLUDE CFLAGS_USER \
-      CFLAGS_APPLICATION CFLAGS_COMPILER CFLAGS_SYSTEM CFLAGS_SHARED \
+      CFLAGS_APPLICATION CFLAGS_COMPILER \
+      CFLAGS_SYSTEM CFLAGS_SHARED \
       CFLAGS_SHARED_USER LDFLAGS_OPTIMIZE LDFLAGS_DEBUG LDFLAGS_USER \
       LDFLAGS_APPLICATION LDFLAGS_COMPILER LDFLAGS_SYSTEM \
       LDFLAGS_SHARED LDFLAGS_SHARED_LIBLINK LDFLAGS_SHARED_USER \
@@ -99,8 +83,8 @@ preconfigfile () {
   puts "    From: ${configfile}"
   puts "    Using: mkconfig-${_MKCONFIG_VERSION} */"
   puts ''
-  puts "#ifndef MKC_INC_${CONFHTAGUC}_H
-#define MKC_INC_${CONFHTAGUC}_H 1
+  puts "#ifndef INC_${CONFHTAGUC}_H
+#define INC_${CONFHTAGUC}_H 1
 "
 }
 
@@ -113,21 +97,13 @@ stdconfigfile () {
 #  define void int
 # endif
 # if ! _key_void || ! _param_void_star
-   typedef char *_pvoid;
+   typedef char *pvoid;
 # else
-   typedef void *_pvoid;
+   typedef void *pvoid;
 # endif
 # if ! _key_const
 #  define const
 # endif
-
-# ifndef _
-#  if _proto_stdc
-#   define _(args) args
-#  else
-#   define _(args) ()
-#  endif
-# endif
 #endif /* MKC_STANDARD_DEFS */
 '
 }
@@ -135,7 +111,7 @@ stdconfigfile () {
 postconfigfile () {
   pc_configfile=$1
   puts "
-#endif /* MKC_INC_${CONFHTAGUC}_H */"
+#endif /* INC_${CONFHTAGUC}_H */"
 }
 
 standard_checks () {
@@ -156,6 +132,12 @@ standard_checks () {
   PH_ALL=T
 }
 
+check_header_reset () {
+  printlabel "" "reset headers"
+  out="${PH_PREFIX}all"
+  rm -f $out
+}
+
 check_hdr () {
   type=$1
   hdr=$2
@@ -181,7 +163,7 @@ check_hdr () {
   file=$hdr
 
   printlabel $name "header: ${file}"
-  checkcache ${_MKCONFIG_PREFIX} $name
+  checkcache $name
   if [ $rc -eq 0 ]; then return; fi
 
   code=""
@@ -196,7 +178,7 @@ check_hdr () {
   fi
   doappend code "
 #include <$file>
-int main () { return (0); }
+int main (int argc, char *argv []) { return 0; }
 "
   rc=1
   _c_chk_compile ${name} "${code}" std
@@ -210,7 +192,7 @@ int main () { return (0); }
     domath CPPCOUNTER "$CPPCOUNTER + 1"
   fi
   printyesno $name $val
-  setdata ${_MKCONFIG_PREFIX} ${name} ${val}
+  setdata ${name} ${val}
 }
 
 check_sys () {
@@ -226,7 +208,7 @@ check_const () {
   name=$nm
 
   printlabel $name "constant: ${constant}"
-  checkcache ${_MKCONFIG_PREFIX} $name
+  checkcache $name
   if [ $rc -eq 0 ]; then return; fi
 
   code=""
@@ -240,7 +222,10 @@ check_const () {
       done
   fi
   doappend code "
-int main () { if (${constant} == 0) { 1; } return (0); }
+int main (int argc, char *argv []) {
+if (${constant} == 0) { 1; }
+return 0;
+}
 "
   do_c_check_compile ${name} "${code}" all
 }
@@ -250,10 +235,14 @@ check_key () {
   name="_key_${keyword}"
 
   printlabel $name "keyword: ${keyword}"
-  checkcache ${_MKCONFIG_PREFIX} $name
+  checkcache $name
   if [ $rc -eq 0 ]; then return; fi
 
-  code="int main () { int ${keyword}; ${keyword} = 1; return (0); }"
+  code="int main (int argc, char *argv []) {
+int ${keyword};
+${keyword} = 1;
+return 0;
+}"
 
   _c_chk_compile ${name} "${code}" std
   rc=$?
@@ -262,14 +251,14 @@ check_key () {
     trc=1
   fi
   printyesno $name $trc
-  setdata ${_MKCONFIG_PREFIX} ${name} ${trc}
+  setdata ${name} ${trc}
 }
 
 check_proto () {
   name=$1
 
   printlabel $name "supported: prototypes"
-  checkcache ${_MKCONFIG_PREFIX} $name
+  checkcache $name
   if [ $rc -eq 0 ]; then return; fi
 
   code='
@@ -291,14 +280,17 @@ check_typ () {
   dosubst type 'star' '*'
 
   printlabel $name "type: ${type}"
-  checkcache ${_MKCONFIG_PREFIX} $name
+  checkcache $name
   if [ $rc -eq 0 ]; then return; fi
 
   code="
 struct xxx { ${type} mem; };
 static struct xxx v;
 struct xxx* f() { return &v; }
-int main () { struct xxx *tmp; tmp = f(); return (0); }
+int main (int argc, char *argv []) {
+struct xxx *tmp; tmp = f();
+return 0;
+}
 "
 
   do_c_check_compile ${name} "${code}" all
@@ -311,29 +303,30 @@ check_define () {
   name=$nm
 
   printlabel $name "defined: ${def}"
-  checkcache ${_MKCONFIG_PREFIX} $name
+  checkcache $name
   if [ $rc -eq 0 ]; then return; fi
 
-  code="int main () {
+  code="int main (int argc, char *argv []) {
 #if defined(${def})
 # define MKC_DEFINED 1
 #endif
 #ifdef MKC_DEFINED
 printf (\"mkc_defined ${def}\");
 #endif
+return 0;
 }"
 
   trc=0
   _c_chk_cpp "$name" "$code" all
   rc=$?
   if [ $rc -eq 0 ]; then
-    egrep -l "mkc_defined" $name.out >/dev/null 2>&1
+    ${grepcmd} -l mkc_defined $name.out >/dev/null 2>&1
     rc=$?
     if [ $rc -eq 0 ]; then
       trc=1
     fi
   fi
-  setdata ${_MKCONFIG_PREFIX} ${name} ${trc}
+  setdata ${name} ${trc}
   printyesno $name $trc
 }
 
@@ -341,7 +334,7 @@ check_param_void_star () {
   name="_param_void_star"
 
   printlabel $name "parameter: void *"
-  checkcache ${_MKCONFIG_PREFIX} $name
+  checkcache $name
   if [ $rc -eq 0 ]; then return; fi
 
   code="
@@ -357,40 +350,6 @@ tparamvs (ptr)
   do_c_check_compile ${name} "${code}" all
 }
 
-check_printf_long_double () {
-  name="_printf_long_double"
-
-  otherlibs="-lintl"
-
-  printlabel $name "printf: long double printable"
-
-  code="int main (int argc, char *argv[]) {
-long double a;
-long double b;
-char t[40];
-a = 1.0;
-b = 2.0;
-a = a / b;
-sprintf (t, \"%.1Lf\", a);
-if (strcmp(t,\"0.5\") == 0) {
-return (0);
-}
-return (1);
-}"
-
-  _c_chk_run "$name" "$code" all
-  rc=$?
-  dlibs=$_retdlibs
-  if [ $rc -eq 0 -a "$dlibs" != "" ]; then
-    cmd="mkc_${_MKCONFIG_PREFIX}_lib_${name}=\"${dlibs}\""
-    eval $cmd
-  fi
-  if [ $rc -eq 0 ]; then trc=1; else trc=0; fi
-  otherlibs=""
-  setdata ${_MKCONFIG_PREFIX} ${name} ${trc}
-  printyesno $name $trc
-}
-
 check_member () {
   shift
   struct=$1
@@ -410,10 +369,15 @@ check_member () {
   name=$nm
 
   printlabel $name "exists: ${struct}.${member}"
-  checkcache ${_MKCONFIG_PREFIX} $name
+  checkcache $name
   if [ $rc -eq 0 ]; then return; fi
 
-  code="int main () { ${struct} s; int i; i = sizeof (s.${member}); }"
+  code="int main (int argc, char *argv []) {
+${struct} s;
+int i;
+i = sizeof (s.${member});
+return 0;
+}"
 
   do_c_check_compile ${name} "${code}" all
 }
@@ -448,13 +412,13 @@ check_memberxdr () {
         mtype=`puts $tmem | sed -e "s/ *${member} *;$//" -e 's/^ *//'`
         puts "  type: ${mtype}" >&9
         trc=1
-        setdata ${_MKCONFIG_PREFIX} xdr_${member} xdr_${mtype}
+        setdata xdr_${member} xdr_${mtype}
       fi
     fi  # found the structure
   fi  # cpp worked
 
   printyesno $name $trc ""
-  setdata ${_MKCONFIG_PREFIX} ${name} ${trc}
+  setdata ${name} ${trc}
 }
 
 check_size () {
@@ -471,7 +435,10 @@ check_size () {
 
   if [ "$MKC_CROSS" = Y ]; then
     puts "## size: cross compiling is active" >&9
-    code="int main () { printf(\"%u\", sizeof(${type})); return (0); }"
+    code="int main (int argc, char *argv []) {
+printf(\"%u\", sizeof(${type}));
+return 0;
+}"
     _c_chk_compile ${name} "${code}" all
     rc=$?
     if [ $rc -eq 0 ]; then
@@ -515,7 +482,10 @@ main () {
     fi
   else
     puts "## size: cross compiling is NOT active" >&9
-    code="int main () { printf(\"%u\", sizeof(${type})); return (0); }"
+    code="int main (int argc, char *argv []) {
+printf(\"%u\", sizeof(${type}));
+return 0;
+}"
     _c_chk_run ${name} "${code}" all
     rc=$?
   fi
@@ -525,12 +495,12 @@ main () {
     val=0
   fi
   if [ $rc -eq 0 -a "$dlibs" != "" ]; then
-    cmd="mkc_${_MKCONFIG_PREFIX}_lib_${name}=\"${dlibs}\""
+    cmd="mkc_lnk_${name}=\"${dlibs}\""
     eval $cmd
   fi
   otherlibs=""
   printyesno_val $name $val
-  setdata ${_MKCONFIG_PREFIX} ${name} ${val}
+  setdata ${name} ${val}
 }
 
 check_dcl () {
@@ -602,7 +572,7 @@ $asmdef
   precc="${oldprecc}"
 
   if [ $rc -eq 0 ]; then
-    egrep -l "[	 *]${funcnm}[	 ]*\(" $name.out >/dev/null 2>&1
+    ${grepcmd} -l "[	 *]${funcnm}[	 ]*\(" $name.out >/dev/null 2>&1
     rc=$?
     if [ $rc -eq 0 ]; then
       trc=1
@@ -646,7 +616,7 @@ $asmdef
         fi
         puts "## tmp(F): ${tmp}" >&9
         nm="_c_arg_${val}_${funcnm}"
-        setdata ${_MKCONFIG_PREFIX} ${nm} "${tmp}"
+        setdata ${nm} "${tmp}"
         domath val "$val + 1"
         c=`puts "${c}" | sed -e 's/^[^,]*//' -e 's/^[	 ,]*//'`
         puts "## c(G): ${c}" >&9
@@ -661,13 +631,13 @@ $asmdef
       fi
       puts "## c(T1): ${c}" >&9
       nm="_c_type_${funcnm}"
-      setdata ${_MKCONFIG_PREFIX} ${nm} "${c}"
+      setdata ${nm} "${c}"
     fi
   fi
 
   printyesno_val $name $ccount ""
   nm="_args_${funcnm}"
-  setdata ${_MKCONFIG_PREFIX} ${nm} ${ccount}
+  setdata ${nm} ${ccount}
 }
 
 check_int_declare () {
@@ -675,10 +645,14 @@ check_int_declare () {
   function=$2
 
   printlabel $name "declared: ${function}"
-  checkcache ${_MKCONFIG_PREFIX} $name
+  checkcache $name
   if [ $rc -eq 0 ]; then return; fi
 
-  code="int main () { int x; x = ${function}; }"
+  code="int main (int argc, char *argv []) {
+int x;
+x = ${function};
+return 0;
+}"
   do_c_check_compile ${name} "${code}" all
 }
 
@@ -687,10 +661,15 @@ check_ptr_declare () {
   function=$2
 
   printlabel $name "declared: ${function}"
-  checkcache ${_MKCONFIG_PREFIX} $name
+  checkcache $name
   if [ $rc -eq 0 ]; then return; fi
 
-  code="int main () { void *x; x = ${function}; }"
+  code="
+int main (int argc, char *argv []) {
+  void *x;
+  x = ${function};
+  return 0;
+}"
   do_c_check_compile ${name} "${code}" all
 }
 
@@ -700,7 +679,7 @@ check_npt () {
 
   has=1
   if [ "${req}" != "" ]; then
-    getdata has ${_MKCONFIG_PREFIX} "${req}"
+    getdata has "${req}"
   fi
   nm="_npt_${func}"
 
@@ -708,11 +687,11 @@ check_npt () {
   proto=$func
 
   printlabel $name "need prototype: ${proto}"
-  checkcache ${_MKCONFIG_PREFIX} $name
+  checkcache $name
   if [ $rc -eq 0 ]; then return; fi
 
   if [ ${has} -eq 0 ]; then
-    setdata ${_MKCONFIG_PREFIX} ${name} 0
+    setdata ${name} 0
     printyesno $name 0
     return
   fi
@@ -726,6 +705,12 @@ CPP_EXTERNS_END
   do_c_check_compile ${name} "${code}" all
 }
 
+check_staticlib () {
+  staticlib=T
+  check_lib "$@"
+  unset staticlib
+}
+
 check_lib () {
   func=$2
   shift;shift
@@ -741,7 +726,7 @@ check_lib () {
     # code to check the cache for which libraries are specified is not written
   else
     printlabel $name "function: ${rfunc}"
-    checkcache ${_MKCONFIG_PREFIX} $name
+    checkcache $name
     if [ $rc -eq 0 ]; then return; fi
   fi
 
@@ -753,25 +738,30 @@ check_lib () {
     code="
 CPP_EXTERNS_BEG
 #undef $rfunc
-typedef void (*_TEST_fun_)(void);
-void $rfunc(void);
-_TEST_fun_ f = (void *) $rfunc;
+typedef char (*test_func)();
+char $rfunc();
+test_func f = (test_func) $rfunc;
 CPP_EXTERNS_END
-int main () {
-if ((void *) f == (void *) $rfunc) { return 0; }
-return 1;
+int main (int argc, char *argv []) {
+  if (f == (test_func) $rfunc) {
+    return 0;
+  }
+  return 1;
 }
 "
   else
     hinc=all
     code="
 CPP_EXTERNS_BEG
-typedef void (*_TEST_fun_)(void);
-_TEST_fun_ f = (void *) $rfunc;
+typedef char (*test_func)();
+test_func f = (test_func) $rfunc;
 CPP_EXTERNS_END
-int main () {
-f(); if ((void *) f == (void *) $rfunc) { return 0; }
-return 1;
+int main (int argc, char *argv []) {
+  f();
+  if (f == (test_func) $rfunc) {
+    return 0;
+  }
+  return 1;
 }
 "
   fi
@@ -785,8 +775,11 @@ return 1;
 
   tag=""
   if [ $rc -eq 0 -a "$dlibs" != "" ]; then
+    if [ "$staticlib" = "T" ]; then
+      dlibs="$LDFLAGS_STATIC_LIB_LINK $dlibs $LDFLAGS_SHARED_LIB_LINK"
+    fi
     tag=" with ${dlibs}"
-    cmd="mkc_${_MKCONFIG_PREFIX}_lib_${name}=\"${dlibs}\""
+    cmd="mkc_lnk_${name}=\"${dlibs}\""
     eval $cmd
   fi
 
@@ -796,13 +789,15 @@ return 1;
       code="
 CPP_EXTERNS_BEG
 #undef $rfunc
-typedef void (*_TEST_fun_)(void);
+typedef char (*test_func)();
 char $rfunc();
-_TEST_fun_ f = (void *) $rfunc;
+test_func f = (test_func) $rfunc;
 CPP_EXTERNS_END
-int main () {
-if ((void *) f == (void *) $rfunc) { return 0; }
-return 1;
+int main (int argc, char *argv []) {
+  if (f == (test_func) $rfunc) {
+    return 0;
+  }
+  return 1;
 }
 "
     else
@@ -816,12 +811,15 @@ where the lib does not exist and the link works!
 On modern systems, this simply isn't necessary.
 */
 extern int ${func}();
-typedef void (*_TEST_fun_)(void);
-_TEST_fun_ f = (void *) $rfunc;
+typedef char (*test_func)();
+test_func f = (test_func) $rfunc;
 CPP_EXTERNS_END
-int main () {
-f(); if ((void *) f == (void *) $rfunc) { return 0; }
-return 1;
+int main (int argc, char *argv []) {
+  f();
+  if (f == (test_func) $rfunc) {
+    return 0;
+  }
+  return 1;
 }
 "
     fi
@@ -835,14 +833,14 @@ return 1;
     tag=""
     if [ $rc -eq 0 -a "$dlibs" != "" ]; then
       tag=" with ${dlibs}"
-      cmd="mkc_${_MKCONFIG_PREFIX}_lib_${name}=\"${dlibs}\""
+      cmd="mkc_lnk_${name}=\"${dlibs}\""
       eval $cmd
     fi
   fi
 
   otherlibs=""
   printyesno $name $trc "$tag"
-  setdata ${_MKCONFIG_PREFIX} ${name} ${trc}
+  setdata ${name} ${trc}
   return $trc
 }
 
@@ -856,13 +854,16 @@ check_class () {
   name=$nm
 
   trc=0
-  code=" int main () { ${class} testclass; } "
+  code=" int main (int argc, char *argv []) {
+${class} testclass;
+return 0;
+} "
 
   if [ "$otherlibs" != "" ]; then
       printlabel $name "class: ${class} [${otherlibs}]"
   else
       printlabel $name "class: ${class}"
-      checkcache ${_MKCONFIG_PREFIX} $name
+      checkcache $name
       if [ $rc -eq 0 ]; then return; fi
   fi
 
@@ -874,13 +875,13 @@ check_class () {
   tag=""
   if [ $rc -eq 0 -a "${dlibs}" != "" ]; then
     tag=" with ${dlibs}"
-    cmd="mkc_${_MKCONFIG_PREFIX}_lib_${name}=\"${dlibs}\""
+    cmd="mkc_lnk_${name}=\"${dlibs}\""
     eval $cmd
   fi
 
   otherlibs=""
   printyesno $name $trc "$tag"
-  setdata ${_MKCONFIG_PREFIX} ${name} ${trc}
+  setdata ${name} ${trc}
 }
 
 output_item () {
@@ -898,9 +899,23 @@ output_item () {
       dosubst tname '_setint_' ''
       puts "#define ${tname} ${val}"
       ;;
-    _setstr_*|_opt_*|_cmd_loc_*)
+    _envquote_*)
+      ;;
+    _env_*)
+      if [ "x${val}" != x ]; then
+        tname=$name
+        dosubst tname '_env_' ''
+        eval q=\${mkc__envquote_${tname}}
+        if [ $q -eq 1 ]; then
+          puts "#define ${tname} \"${val}\""
+        else
+          puts "#define ${tname} ${val}"
+        fi
+      fi
+      ;;
+    _setstr_*|_cmd_loc_*)
       tname=$name
-      dosubst tname '_setstr_' '' '_opt_' ''
+      dosubst tname '_setstr_' ''
       puts "#define ${tname} \"${val}\""
       ;;
     _hdr_*|_sys_*|_command_*)
