@@ -26,8 +26,6 @@ check_extension () {
 check_objext () {
   name=OBJ_EXT
   printlabel $name "extension: object"
-  checkcache_val ${_MKCONFIG_PREFIX} $name
-  if [ $? -eq 0 ]; then return; fi
 
   TMPF=objext
 
@@ -52,14 +50,12 @@ int main ()
   fi
 
   printyesno_val $name "${OBJ_EXT}"
-  setdata ${_MKCONFIG_PREFIX} $name "${OBJ_EXT}"
+  setdata $name "${OBJ_EXT}"
 }
 
 check_exeext () {
   name=EXE_EXT
   printlabel $name "extension: executable"
-  checkcache_val ${_MKCONFIG_PREFIX} $name
-  if [ $? -eq 0 ]; then return; fi
 
   TMPF=exeext
 
@@ -85,7 +81,7 @@ int main ()
   fi
 
   printyesno_val $name "${EXE_EXT}"
-  setdata ${_MKCONFIG_PREFIX} $name "${EXE_EXT}"
+  setdata $name "${EXE_EXT}"
 }
 
 check_shlibext () {
@@ -109,7 +105,7 @@ check_shlibext () {
   esac
 
   printyesno_val $name "$SHLIB_EXT"
-  setdata ${_MKCONFIG_PREFIX} $name "$SHLIB_EXT"
+  setdata $name "$SHLIB_EXT"
 }
 
 
