@@ -23,8 +23,6 @@ check_cmd_msgfmt () {
   name=XMSGFMT
 
   printlabel $name "command: locate msgfmt"
-  checkcache_val ${_MKCONFIG_PREFIX} $name
-  if [ $? -eq 0 ]; then return; fi
 
   locatecmd xmsgfmt msgfmt
   locatecmd xgmsgfmt gmsgfmt
@@ -44,5 +42,5 @@ check_cmd_msgfmt () {
   fi
 
   printyesno_val XMSGFMT $xmsgfmt
-  setdata ${_MKCONFIG_PREFIX} "XMSGFMT" "${xmsgfmt}"
+  setdata "XMSGFMT" "${xmsgfmt}"
 }
